Blob Blame History Raw
diff --git configure.ac configure.ac
index 0bd3070..1c27fa0 100644
--- configure.ac
+++ configure.ac
@@ -160,7 +160,6 @@ AM_PATH_PYTHON([2.6], [], AC_MSG_ERROR([Python interpreter 2.6 or 2.7 required])
 AC_PYTHON_MODULE([pywbem], [Required])
 AC_PYTHON_MODULE([M2Crypto], [Required])
 AC_PYTHON_MODULE([argparse], [Required])
-AC_PYTHON_MODULE([yaml], [Required])
 
 dnl ==========================================================================
 dnl Check for libmicrohttpd and json-c as it is needed for REST API daemon
diff --git test/plugin_test.py test/plugin_test.py
index e92497c..8e0d8bc 100755
--- test/plugin_test.py
+++ test/plugin_test.py
@@ -26,7 +26,6 @@ import argparse
 import collections
 import atexit
 import sys
-import yaml
 import re
 import os
 import tempfile
@@ -1273,10 +1272,15 @@ def dump_results():
     unittest.main exits when done so we need to register this handler to
     get our results out.
 
-    output details (yaml) results of what we called, how it finished and how
-    long it took.
+    If PyYAML is available we will output detailed results, else we will
+    output nothing.  The detailed output results of what we called,
+    how it finished and how long it took.
     """
-    sys.stdout.write(yaml.dump(dict(methods_called=results, stats=stats)))
+    try:
+        import yaml
+        sys.stdout.write(yaml.dump(dict(methods_called=results, stats=stats)))
+    except ImportError:
+        sys.stdout.write("NOTICE: Install PyYAML for detailed test results\n")
 
 
 def add_our_params():